############
experimental
############

Experimental tools are not part of the test-suite, and might not be production-ready. All tools in this module must be imported via:

.. code-block:: python

    from toolbox.experimental import <tool>

Tools here are proof-of-concept and are not recommended to be used in production.

----

*************
asyncdispatch
*************

.. code-block:: python

    from toolbox.experimental import asyncdispatch

.. autofunction:: toolbox.experimental.asyncdispatch.asyncdispatch
